pytilities.test.event.dispatcher.InitTestCase

Package pytilities :: Package test :: Package event :: Module dispatcher :: Class InitTestCase |
[hide private]
[frames] | no frames]

# Class InitTestCase

source code

           object --+
                    |
    unittest.TestCase --+
                        |
                       InitTestCase

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
setUp(self) Hook method for setting up the test fixture before exercising it. | source code
test_fail_no_events(self) | source code
test_success(self) | source code
test_success_owner(self) | source code
Inherited from `unittest.TestCase`: `__call__`, `__eq__`, `__hash__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `shortDescription`, `tearDown` Inherited from `unittest.TestCase` (private): `_exc_info` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### setUp(self) | source code
Hook method for setting up the test fixture before exercising it. Overrides: unittest.TestCase.setUp (inherited documentation)